@@ -20,16 +20,15 @@ G_BEGIN_DECLS
 typedef struct _GladeEditor          GladeEditor;
 typedef struct _GladeEditorClass     GladeEditorClass;
 typedef struct _GladeEditorTable     GladeEditorTable;
-typedef enum   _GladeEditorTableType GladeEditorTableType;
 
-enum _GladeEditorTableType
+typedef enum _GladeEditorTableType
 {
 	TABLE_TYPE_GENERAL,
 	TABLE_TYPE_COMMON,
 	TABLE_TYPE_PACKING,
 	TABLE_TYPE_ATK,
 	TABLE_TYPE_QUERY
-};
+} GladeEditorTableType;
 
 /* The GladeEditor is a window that is used to display and modify widget
  * properties. The glade editor contains the details of the selected
@@ -46,35 +45,35 @@ struct _GladeEditor
 				     * if no widgets are selected
 				     */
 
-	GladeWidgetClass *loaded_class; /* A pointer to the loaded
-					 * GladeWidgetClass. Note that we can
-					 * have a class loaded without a
-					 * loaded_widget. For this reason we
-					 * can't use loaded_widget->class.
-					 * When a widget is selected we load
-					 * this class in the editor first and
-					 * then fill the values of the inputs
-					 * with the GladeProperty items.
-					 * This is usefull for not having
-					 * to redraw/container_add the widgets
-					 * when we switch from widgets of the
-					 * same class
-					 */
+	GladeWidgetAdaptor *loaded_adaptor; /* A pointer to the loaded
+					     * GladeWidgetAdaptor. Note that we can
+					     * have a class loaded without a
+					     * loaded_widget. For this reason we
+					     * can't use loaded_widget->adaptor.
+					     * When a widget is selected we load
+					     * this class in the editor first and
+					     * then fill the values of the inputs
+					     * with the GladeProperty items.
+					     * This is usefull for not having
+					     * to redraw/container_add the widgets
+					     * when we switch from widgets of the
+					     * same class
+					     */
 
 
 	/* The editor has (at this moment) four tabs; these are pointers to the 
-	 * vboxes inside each tab. The vboxes are wrapped into a scrolled window.
-	 * The vbox_* widgets are deparented and parented with
+	 * widget inside each tab. The widgets are wrapped into a scrolled window.
+	 * The page_* widgets are deparented and parented with
 	 * ((GladeEditorTable *)etable)->table_widget when a widget is selected and
-	 * the correct editor table is found. The exception is `vbox_signals' which
+	 * the correct editor table is found. The exception is `page_signals' which
 	 * always contains the same signal editor widget which simply reloads when
 	 * loading a widget.
 	 */
-	GtkWidget *vbox_widget;
-	GtkWidget *vbox_packing;
-	GtkWidget *vbox_common;
-	GtkWidget *vbox_signals;
-	GtkWidget *vbox_atk;
+	GtkWidget *page_widget;
+	GtkWidget *page_packing;
+	GtkWidget *page_common;
+	GtkWidget *page_signals;
+	GtkWidget *page_atk;
 
 	GladeSignalEditor *signal_editor; /* The signal editor packed into vbox_signals
 					   */
@@ -108,6 +107,17 @@ struct _GladeEditor
 	gulong project_closed_signal_id; /* Unload widget when widget's project closes.
 					  */
 	
+	GtkWidget *reset_button; /* The reset button
+				  */
+	
+	GtkWidget *info_button; /* The actual informational button
+				 */
+
+	gboolean show_info; /* Whether or not to show an informational button
+			     */
+	gboolean show_context_info; /* Whether or not to show an informational
+				     * button for each property and signal.
+				     */
 };
 
 struct _GladeEditorClass
@@ -117,6 +127,12 @@ struct _GladeEditorClass
 	void   (*add_signal) (GladeEditor *editor, const char *id_widget,
 			      GType type_widget, guint id_signal,
 			      const char *callback_name);
+
+	void   (*gtk_doc_search) (GladeEditor *,
+				  const gchar *,
+				  const gchar *,
+				  const gchar *);
+
 };
 
 /* For each glade widget class that we have modified, we create a
@@ -133,9 +149,9 @@ struct _GladeEditorTable
 			      * editor arround.
 			      */
 	
-	GladeWidgetClass *glade_widget_class; /* The GladeWidgetClass this
-					       * table belongs to.
-					       */
+	GladeWidgetAdaptor *adaptor; /* The GladeWidgetAdaptor this
+				      * table belongs to.
+				      */
 
 	GtkWidget *table_widget; /* This widget is a gtk_vbox that is displayed
 				  * in the glade-editor when a widget of this
@@ -179,6 +195,16 @@ void         glade_editor_update_widget_name (GladeEditor *editor);
 LIBGLADEUI_API
 gboolean     glade_editor_query_dialog       (GladeEditor *editor,
 					      GladeWidget *widget);
+LIBGLADEUI_API
+void         glade_editor_show_info          (GladeEditor *editor);
+LIBGLADEUI_API
+void         glade_editor_show_context_info  (GladeEditor *editor);
+LIBGLADEUI_API
+void         glade_editor_hide_info          (GladeEditor *editor);
+LIBGLADEUI_API
+void         glade_editor_hide_context_info  (GladeEditor *editor);
+
+
 
 G_END_DECLS
 
