@@ -38,8 +38,9 @@
 #include "glade-catalog.h"
 #include "glade-project.h"
 #include "glade-widget.h"
-#include "glade-widget-class.h"
+#include "glade-widget-adaptor.h"
 #include <glib/gi18n-lib.h>
+#include <gdk/gdk.h>
 
 #define GLADE_PALETTE_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object),\
 					  GLADE_TYPE_PALETTE,                   \
@@ -49,22 +50,25 @@ struct _GladePalettePrivate
 {
 	const GList *catalogs;        /* List of widget catalogs */
 
-	GtkWidget *selector;    /* Selector item button */
+	GtkWidget *selector_hbox;	
+	GtkWidget *selector_button;
+
 	GtkWidget *tray;	/* Where all the item groups are contained */
 
-	GladeWidgetClass *current_item_class; /* The currently selected item class */
+	GladePaletteItem *current_item; /* The currently selected item */
 
 	GSList *sections;   	         /* List of GladePaletteExpanders */ 
-	GSList *items_radio_group;       /* Radio group for palette item buttons */
 
 	GtkTooltips *tooltips;           /* Tooltips for the item buttons */
-	GtkTooltips *selector_tooltips;  /* Tooltip for the selector */
+	GtkTooltips *static_tooltips;    /* These tooltips never get disabled */
 
-	GtkSizeGroup *size_group;        /* All items have the same width */
+	GtkSizeGroup *size_group;        /* All items have the same dimensions */
 
 	GladeItemAppearance item_appearance;
 
 	gboolean use_small_item_icons;
+	
+	gboolean sticky_selection_mode; /* whether sticky_selection mode has been enabled */
 };
 
 enum
@@ -76,20 +80,66 @@ enum
 enum
 {
 	PROP_0,
-	PROP_CURRENT_ITEM_CLASS,
+	PROP_CURRENT_ITEM,
 	PROP_ITEM_APPEARANCE,
-	PROP_USE_SMALL_ITEM_ICONS
+	PROP_USE_SMALL_ITEM_ICONS,
+	PROP_SHOW_SELECTOR_BUTTON,
+	PROP_CATALOGS
 };
 
 static guint glade_palette_signals[LAST_SIGNAL] = {0};
 
-static void glade_palette_append_item_group (GladePalette     *palette, 
-					       GladeWidgetGroup *group);
+static void glade_palette_append_item_group (GladePalette *palette, GladeWidgetGroup *group);
 
 static void glade_palette_update_appearance (GladePalette *palette);
 
 static GtkVBoxClass *parent_class = NULL;
 
+
+G_DEFINE_TYPE(GladePalette, glade_palette, GTK_TYPE_VBOX)
+
+void
+selector_button_toggled_cb (GtkToggleButton *button, GladePalette *palette)
+{
+	if (gtk_toggle_button_get_active (button))
+	{
+		glade_palette_deselect_current_item (palette, FALSE);
+	}
+	else if (glade_palette_get_current_item (palette) == FALSE)
+	{
+		gtk_toggle_button_set_active (button, TRUE);
+	}
+}
+
+static void
+glade_palette_set_catalogs (GladePalette *palette, GList *catalogs)
+{
+	GladePalettePrivate *priv;
+	GList *l;
+
+	g_return_if_fail (GLADE_IS_PALETTE (palette));
+	priv = GLADE_PALETTE_GET_PRIVATE (palette);
+
+	priv->catalogs = catalogs;
+
+	for (l = (GList *) priv->catalogs; l; l = l->next) 
+	{
+		GList *groups = glade_catalog_get_widget_groups (GLADE_CATALOG (l->data));
+
+		for (; groups; groups = groups->next)
+		{
+			GladeWidgetGroup *group = GLADE_WIDGET_GROUP (groups->data);
+
+			if (glade_widget_group_get_adaptors (group)) 
+				glade_palette_append_item_group (palette, group);
+		}
+	}
+	
+	gtk_widget_show_all (priv->tray);
+	
+	g_object_unref (priv->size_group);
+}
+
 /**
  * glade_palette_set_item_appearance:
  * @palette: a #GladePalette
@@ -140,6 +190,33 @@ glade_palette_set_use_small_item_icons (GladePalette *palette, gboolean use_smal
 
 }
 
+/**
+ * glade_palette_set_show_selector_button:
+ * @palette: a #GladePalette
+ * @show_selector_button: whether to show selector button
+ *
+ * Sets whether to show the internal widget selector button
+ */
+void
+glade_palette_set_show_selector_button (GladePalette *palette, gboolean show_selector_button)
+{
+	GladePalettePrivate *priv;
+	g_return_if_fail (GLADE_IS_PALETTE (palette));
+	priv = GLADE_PALETTE_GET_PRIVATE (palette);
+
+	if (GTK_WIDGET_VISIBLE (priv->selector_hbox) != show_selector_button)
+	{
+		if (show_selector_button)
+			gtk_widget_show (priv->selector_hbox);
+		else
+			gtk_widget_hide (priv->selector_hbox);
+			
+		g_object_notify (G_OBJECT (palette), "show-selector-button");
+		
+	}
+
+}
+
 static void 
 glade_palette_set_property (GObject *object,
 		            guint prop_id,
@@ -156,6 +233,12 @@ glade_palette_set_property (GObject *object,
 		case PROP_ITEM_APPEARANCE:
 			glade_palette_set_item_appearance (palette, g_value_get_enum (value));
 			break;
+		case PROP_SHOW_SELECTOR_BUTTON:
+			glade_palette_set_show_selector_button (palette, g_value_get_boolean (value));
+			break;
+		case PROP_CATALOGS:
+			glade_palette_set_catalogs (palette, g_value_get_pointer (value));
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -173,15 +256,21 @@ glade_palette_get_property (GObject    *object,
 
 	switch (prop_id)
 	{
-		case PROP_CURRENT_ITEM_CLASS:
-			g_value_set_pointer (value, (gpointer) priv->current_item_class);
+		case PROP_CURRENT_ITEM:
+			g_value_set_pointer (value, (gpointer) glade_palette_item_get_adaptor (priv->current_item));
 			break;
 		case PROP_USE_SMALL_ITEM_ICONS:
 			g_value_set_boolean (value, priv->use_small_item_icons);
 			break;
+		case PROP_SHOW_SELECTOR_BUTTON:
+			g_value_set_boolean (value, GTK_WIDGET_VISIBLE (priv->selector_button));
+			break;
 		case PROP_ITEM_APPEARANCE:
 			g_value_set_enum (value, priv->item_appearance);
-			break;			
+			break;
+		case PROP_CATALOGS:
+			g_value_set_pointer (value, (gpointer) priv->catalogs);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;			
@@ -201,7 +290,7 @@ glade_palette_dispose (GObject *object)
 	priv->catalogs = NULL;
 
 	g_object_unref (priv->tooltips);
-	g_object_unref (priv->selector_tooltips);
+	g_object_unref (priv->static_tooltips);
 
 	G_OBJECT_CLASS (parent_class)->dispose (object);
 
@@ -223,14 +312,15 @@ glade_palette_finalize (GObject *object)
 }
 
 static void
-glade_palette_class_init (GladePaletteClass *class)
+glade_palette_class_init (GladePaletteClass *klass)
 {
 	GObjectClass *object_class;
 
-	object_class = G_OBJECT_CLASS (class);
-	parent_class = g_type_class_peek_parent (class);
+	object_class = G_OBJECT_CLASS (klass);
+	parent_class = g_type_class_peek_parent (klass);
 
-	class->toggled = NULL;
+	klass->toggled = NULL;
+	
 	object_class->get_property = glade_palette_get_property;
 	object_class->set_property = glade_palette_set_property;
 	object_class->dispose = glade_palette_dispose;
@@ -264,52 +354,88 @@ glade_palette_class_init (GladePaletteClass *class)
 							       G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
-					 PROP_CURRENT_ITEM_CLASS,
-					 g_param_spec_pointer  ("current-item-class",
+					 PROP_ITEM_APPEARANCE,
+					 g_param_spec_boolean ("show-selector-button",
+							       "Show Selector Button",
+							       "Whether to show the internal selector button",
+							       TRUE,
+							       G_PARAM_READWRITE));
+
+	g_object_class_install_property (object_class,
+					 PROP_CURRENT_ITEM,
+					 g_param_spec_pointer  ("current-item",
 							        "Current Item Class",
-							        "The GladeWidgetClass of the currently selected item",
+							        "The GladeWidgetAdaptor of the currently selected item",
 							        G_PARAM_READABLE));
+							        
+	g_object_class_install_property (object_class,
+					 PROP_CATALOGS,
+					 g_param_spec_pointer  ("catalogs",
+							        "Widget catalogs",
+							        "The widget catalogs for the palette",
+							        G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
 
 	g_type_class_add_private (object_class, sizeof (GladePalettePrivate));
 }
 
-
 static void
 glade_palette_on_button_toggled (GtkWidget *button, GladePalette *palette)
 {
 	GladePalettePrivate *priv;
-
+	GdkModifierType mask;
+	GladeWidgetAdaptor *adaptor;
+	
 	g_return_if_fail (GLADE_IS_PALETTE (palette));
 	g_return_if_fail (GTK_IS_TOGGLE_BUTTON (button));
 	priv = GLADE_PALETTE_GET_PRIVATE (palette);
 
-	/* we are interested only in buttons which toggle from inactive to active */
+	/* if we are toggling currently active item into non-active state */
+	if (priv->current_item == GLADE_PALETTE_ITEM (button))
+	{
+		priv->current_item = NULL;
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->selector_button), TRUE);	
+
+		priv->sticky_selection_mode = FALSE;
+		
+		g_signal_emit (G_OBJECT (palette), glade_palette_signals[TOGGLED], 0);
+
+		return;
+	}
+
+	/* now we are interested only in buttons which toggle from inactive to active */
 	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
 		return;
+	
+	if (priv->current_item && (GLADE_PALETTE_ITEM (button) != priv->current_item))
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->current_item), FALSE);
+		
+	priv->current_item = GLADE_PALETTE_ITEM (button);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->selector_button), FALSE);	
+	
+	/* check whether to enable sticky selection */
+	adaptor = glade_palette_item_get_adaptor (GLADE_PALETTE_ITEM (button));	
+	gdk_window_get_pointer (button->window, NULL, NULL, &mask);
+  	priv->sticky_selection_mode = (!GWA_IS_TOPLEVEL (adaptor)) && (mask & GDK_CONTROL_MASK);
 
-	if (button == priv->selector)
-		priv->current_item_class = NULL;
-	else
-		priv->current_item_class = glade_palette_item_get_widget_class (GLADE_PALETTE_ITEM (button));
 
 	g_signal_emit (G_OBJECT (palette), glade_palette_signals[TOGGLED], 0);
 }
 
 static GtkWidget*
-glade_palette_new_item (GladePalette *palette, GladeWidgetClass *widget_class)
+glade_palette_new_item (GladePalette *palette, GladeWidgetAdaptor *adaptor)
 {
 	GladePalettePrivate *priv;
 	GtkWidget *item;
 
 	g_return_val_if_fail (GLADE_IS_PALETTE (palette), NULL);
-	g_return_val_if_fail (GLADE_IS_WIDGET_CLASS (widget_class), NULL);
+	g_return_val_if_fail (GLADE_IS_WIDGET_ADAPTOR (adaptor), NULL);
 	priv = GLADE_PALETTE_GET_PRIVATE (palette);
 
-	item = glade_palette_item_new (widget_class, GTK_RADIO_BUTTON (priv->selector));
+	item = glade_palette_item_new (adaptor);
 
 	glade_palette_item_set_appearance (GLADE_PALETTE_ITEM (item), priv->item_appearance);
 
-	gtk_tooltips_set_tip (priv->tooltips, item, widget_class->palette_name, NULL);
+	gtk_tooltips_set_tip (priv->tooltips, item, adaptor->title, NULL);
 
 	g_signal_connect (G_OBJECT (item), "toggled",
 			  G_CALLBACK (glade_palette_on_button_toggled), palette);
@@ -334,12 +460,12 @@ glade_palette_new_item_group (GladePalette *palette, GladeWidgetGroup *group)
 	box = glade_palette_box_new ();
 
 	/* Go through all the widget classes in this catalog. */
-	for (l = glade_widget_group_get_widget_classes (group); l; l = l->next)
+	for (l = glade_widget_group_get_adaptors (group); l; l = l->next)
 	{
-		GladeWidgetClass *class =  GLADE_WIDGET_CLASS (l->data);
+		GladeWidgetAdaptor *adaptor =  GLADE_WIDGET_ADAPTOR (l->data);
 
 		/* Create new item */
-		item = glade_palette_new_item (palette, class);
+		item = glade_palette_new_item (palette, adaptor);
 		gtk_size_group_add_widget (priv->size_group, GTK_WIDGET (item));
 		gtk_container_add (GTK_CONTAINER (box), item);
 
@@ -429,175 +555,77 @@ glade_palette_update_appearance (GladePalette *palette)
 }
 
 static GtkWidget*
-glade_palette_selector_new (GladePalette *palette)
+glade_palette_create_selector_button (GladePalette *palette)
 {
-	GladePalettePrivate *priv;
-	GtkWidget *hbox;
+	GtkWidget *selector;
 	GtkWidget *image;
 	gchar *path;
 
-	priv = GLADE_PALETTE_GET_PRIVATE (palette);
-
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 1);
-
-	/* Create selector button */
-	priv->selector = gtk_radio_button_new (priv->items_radio_group);
+	/* create selector button */
+	selector = gtk_toggle_button_new ();
+	
+	gtk_container_set_border_width (GTK_CONTAINER (selector), 0);
 
 	path = g_build_filename (glade_pixmaps_dir, "selector.png", NULL);
 	image = gtk_image_new_from_file (path);
-	g_free (path);
+	gtk_widget_show (image);
 	
-	gtk_container_add (GTK_CONTAINER (priv->selector), image);
-	gtk_button_set_relief (GTK_BUTTON (priv->selector), GTK_RELIEF_NONE);
-	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (priv->selector), FALSE);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->selector), TRUE);
+	gtk_container_add (GTK_CONTAINER (selector), image);
+	gtk_button_set_relief (GTK_BUTTON (selector), GTK_RELIEF_NONE);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (selector), TRUE);
 
-	gtk_tooltips_set_tip (priv->selector_tooltips, priv->selector, _("Widget Selector"), NULL);
-
-	g_signal_connect (G_OBJECT (priv->selector), "toggled",
-			  G_CALLBACK (glade_palette_on_button_toggled), 
+	g_signal_connect (G_OBJECT (selector), "toggled",
+			  G_CALLBACK (selector_button_toggled_cb), 
 			  palette);
 
-	/* Pack button into hbox */
-	gtk_box_pack_start (GTK_BOX (hbox), priv->selector, FALSE, FALSE, 1);
+	g_free (path);
 
-
-	return hbox;
+	return selector;
 }
 
 static void
 glade_palette_init (GladePalette *palette)
 {
 	GladePalettePrivate *priv;
-	GtkWidget *widget;
+	GtkWidget *sw;
 
-	priv = GLADE_PALETTE_GET_PRIVATE (palette);
+	priv = palette->priv = GLADE_PALETTE_GET_PRIVATE (palette);
 
 	priv->catalogs = NULL;
-	priv->current_item_class = NULL;
-	priv->items_radio_group = NULL;
+	priv->current_item = NULL;
 	priv->sections = NULL;
 	priv->item_appearance = GLADE_ITEM_ICON_ONLY;
 	priv->use_small_item_icons = FALSE;
+	priv->sticky_selection_mode = FALSE;
 
+	/* create selector button */
+	priv->selector_button = glade_palette_create_selector_button (palette);
+	priv->selector_hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (priv->selector_hbox), priv->selector_button, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (palette), priv->selector_hbox, FALSE, FALSE, 0);
+	gtk_widget_show (priv->selector_button);
+	gtk_widget_show (priv->selector_hbox);
 
-	/* Create tooltips */
+	/* create tooltips */
 	priv->tooltips = gtk_tooltips_new ();
 	g_object_ref (priv->tooltips);
 	gtk_object_sink (GTK_OBJECT (priv->tooltips));
+	priv->static_tooltips = gtk_tooltips_new ();
+	g_object_ref (priv->static_tooltips);
+	gtk_object_sink (GTK_OBJECT (priv->static_tooltips));
 
-	priv->selector_tooltips = gtk_tooltips_new ();
-	g_object_ref (priv->selector_tooltips);
-	gtk_object_sink (GTK_OBJECT (priv->selector_tooltips));
+	gtk_tooltips_set_tip (priv->static_tooltips, priv->selector_button, _("Widget selector"), NULL);
 
+	/* create size group */
+	priv->size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+	gtk_size_group_set_ignore_hidden (priv->size_group, FALSE);
 
-	/* Create Selector */
-	widget = glade_palette_selector_new (palette);
-	gtk_box_pack_start (GTK_BOX (palette), widget, FALSE, FALSE, 0);
-
-
-	/* Add items tray (via a scrolled window) */
+	/* add items tray (via a scrolled window) */
 	priv->tray = gtk_vbox_new (FALSE, 0);
 	g_object_ref (G_OBJECT (priv->tray));
 	gtk_object_sink (GTK_OBJECT (priv->tray));
 	gtk_container_set_border_width (GTK_CONTAINER (priv->tray), 1);
-
-	/* Create Size Group */
-	priv->size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	gtk_size_group_set_ignore_hidden (priv->size_group, FALSE);
-}
-
-GType
-glade_palette_get_type (void)
-{
-	static GType type = 0;
-
-	if (!type)
-	{
-		static const GTypeInfo info =
-		{
-			sizeof (GladePaletteClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) glade_palette_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (GladePalette),
-			0,
-			(GInstanceInitFunc) glade_palette_init
-		};
-
-		type = g_type_register_static (GTK_TYPE_VBOX, "GladePalette", &info, 0);
-	}
-
-	return type;
-}
-
-/**
- * glade_palette_get_current_item_class:
- * @palette: a #GladePalette
- *
- * Gets the #GladeWidgetClass of the currently selected item.
- *
- * Returns: the #GladeWidgetClass of currently selected item, or NULL
- *          if no item is selected.
- */
-GladeWidgetClass *
-glade_palette_get_current_item_class (GladePalette *palette)
-{
-	GladePalettePrivate *priv;
-	g_return_val_if_fail (GLADE_IS_PALETTE (palette), NULL);
-	priv = GLADE_PALETTE_GET_PRIVATE (palette);
-
-
-	return priv->current_item_class;
-
-}
-
-/**
- * glade_palette_new:
- * @catalogs: the widget catalogs for the palette.
- * @item_appearance: the appearance of the palette items.
- *
- * Creates a new #GladePalette widget
- *
- * Returns: a new #GladePalette
- */
-GtkWidget*
-glade_palette_new (const GList *catalogs, GladeItemAppearance item_appearance)
-{
-	GladePalette *palette;
-	GladePalettePrivate *priv;
-	GtkWidget *sw;
-	GList *l;
-
-	g_return_val_if_fail (catalogs != NULL, NULL);
-
-	palette = g_object_new (GLADE_TYPE_PALETTE,
-				"spacing", 2, 
-				"item-appearance", item_appearance,
-				NULL);
-
-	g_return_val_if_fail (palette != NULL, NULL);
-
-	priv = GLADE_PALETTE_GET_PRIVATE (palette);
-
-	priv->catalogs = catalogs;
-
-	for (l = (GList *) priv->catalogs; l; l = l->next) 
-	{
-		GList *groups = glade_catalog_get_widget_groups (GLADE_CATALOG (l->data));
-
-		for (; groups; groups = groups->next)
-		{
-			GladeWidgetGroup *group = GLADE_WIDGET_GROUP (groups->data);
-
-			if (glade_widget_group_get_widget_classes (group)) 
-				glade_palette_append_item_group (palette, group);
-		}
-	}
-
+	
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 					GTK_POLICY_NEVER,
@@ -608,7 +636,58 @@ glade_palette_new (const GList *catalogs, GladeItemAppearance item_appearance)
 
 	gtk_box_pack_start (GTK_BOX (palette), sw, TRUE, TRUE, 0);
 
-	g_object_unref (priv->size_group);
+
+	gtk_widget_show (sw);
+	gtk_widget_show (priv->tray);
+	
+	gtk_widget_set_no_show_all (GTK_WIDGET (palette), TRUE);
+}
+
+/**
+ * glade_palette_get_current_item:
+ * @palette: a #GladePalette
+ *
+ * Gets the #GladeWidgetAdaptor of the currently selected item.
+ *
+ * Returns: the #GladeWidgetAdaptor of currently selected item, or NULL
+ *          if no item is selected.
+ */
+GladeWidgetAdaptor *
+glade_palette_get_current_item (GladePalette *palette)
+{
+	g_return_val_if_fail (GLADE_IS_PALETTE (palette), NULL);
+
+	if (palette->priv->current_item)
+	{
+		return glade_palette_item_get_adaptor (palette->priv->current_item);
+	}
+	else
+	{
+		return NULL;
+	}
+
+}
+
+/**
+ * glade_palette_new:
+ * @catalogs: the widget catalogs for the palette.
+ *
+ * Creates a new #GladePalette widget
+ *
+ * Returns: a new #GladePalette
+ */
+GtkWidget*
+glade_palette_new (const GList *catalogs)
+{
+	GladePalette *palette;
+
+	g_return_val_if_fail (catalogs != NULL, NULL);
+
+	palette = g_object_new (GLADE_TYPE_PALETTE,
+				"spacing", 2, 
+				"item-appearance", GLADE_ITEM_ICON_ONLY,
+				"catalogs", catalogs,
+				NULL);
 
 	return GTK_WIDGET (palette);
 }
@@ -616,17 +695,28 @@ glade_palette_new (const GList *catalogs, GladeItemAppearance item_appearance)
 /**
  * glade_palette_deselect_current_item:
  * @palette: a #GladePalette
+ * @sticky_aware: whether to consider sticky selection mode
  *
  * Deselects the currently selected item
  */
 void
-glade_palette_deselect_current_item (GladePalette *palette)
+glade_palette_deselect_current_item (GladePalette *palette, gboolean sticky_aware)
 {
-	GladePalettePrivate *priv;
 	g_return_if_fail (GLADE_IS_PALETTE (palette));
-	priv = GLADE_PALETTE_GET_PRIVATE (palette);
 
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->selector), TRUE);
+	if (sticky_aware && palette->priv->sticky_selection_mode)
+		return;
+
+	if (palette->priv->current_item)
+	{
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (palette->priv->current_item), FALSE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (palette->priv->selector_button), TRUE);		
+		
+		palette->priv->current_item = NULL;
+
+		g_signal_emit (G_OBJECT (palette), glade_palette_signals[TOGGLED], 0);
+	}
+	
 }
 
 /**
@@ -637,13 +727,10 @@ glade_palette_deselect_current_item (GladePalette *palette)
  */
 GladeItemAppearance
 glade_palette_get_item_appearance (GladePalette *palette)
-{
-	GladePalettePrivate *priv;
-	g_return_val_if_fail (GLADE_IS_PALETTE (palette), 
-			      GLADE_ITEM_ICON_ONLY);
-	priv = GLADE_PALETTE_GET_PRIVATE (palette);
+{;
+	g_return_val_if_fail (GLADE_IS_PALETTE (palette), GLADE_ITEM_ICON_ONLY);
 
-	return priv->item_appearance;
+	return palette->priv->item_appearance;
 }
 
 /**
@@ -655,11 +742,21 @@ glade_palette_get_item_appearance (GladePalette *palette)
 gboolean
 glade_palette_get_use_small_item_icons (GladePalette *palette)
 {
-	GladePalettePrivate *priv;
 	g_return_val_if_fail (GLADE_IS_PALETTE (palette), FALSE);
-	priv = GLADE_PALETTE_GET_PRIVATE (palette);
-
-	return priv->use_small_item_icons;
-
 
+	return palette->priv->use_small_item_icons;
+}
+
+/**
+ * glade_palette_get_show_selector_button:
+ * @palette: a #GladePalette
+ *
+ * Returns: Whether the selector button is visible
+ */
+gboolean
+glade_palette_get_show_selector_button (GladePalette *palette)
+{
+	g_return_val_if_fail (GLADE_IS_PALETTE (palette), FALSE);
+
+	return GTK_WIDGET_VISIBLE (palette->priv->selector_hbox);
 }
