@@ -32,45 +32,6 @@ typedef enum {
 	GPC_ACCEL_PROPERTY
 } GPCType;
 
-/**
- * GladeVerifyPropertyFunc:
- * @object: A #GObject
- * @value: The #GValue
- *
- * This delagate function is always called whenever setting any
- * properties with the exception of load time, and copy/paste time
- * (basicly the two places where we recreate a hierarchy that we
- * already know "works"
- *
- * Returns: whether or not its OK to set @value on @object
- */
-typedef gboolean (* GladeVerifyPropertyFunc) (GObject      *object,
-					      const GValue *value);
-
-/**
- * GladeSetPropertyFunc:
- * @object: A #GObject
- * @value: The #GValue
- *
- * This delagate function is used to apply the property value on
- * the runtime object.
- *
- * Sets @value on @object for a given #GladePropertyClass
- */
-typedef void     (* GladeSetPropertyFunc)    (GObject      *object,
-					      const GValue *value);
-
-/**
- * GladeGetPropertyFunc:
- * @object: A #GObject
- * @value: The #GValue
- *
- * Gets @value on @object for a given #GladePropertyClass
- */
-typedef void     (* GladeGetPropertyFunc)    (GObject      *object,
-					      GValue       *value);
-
-
 struct _GladePropertyClass
 {
 	GPCType type; /* A symbolic type used to load/save properties differently
@@ -94,10 +55,10 @@ struct _GladePropertyClass
 	gchar *tooltip; /* The default tooltip for the property editor rows.
 			 */
 
-	gboolean virtual; /* Whether this is a virtual property with its pspec supplied
-			   * via the catalog (or hard code-paths); or FALSE if its a real
-			   * GObject introspected property
-			   */
+	gboolean virt; /* Whether this is a virtual property with its pspec supplied
+			* via the catalog (or hard code-paths); or FALSE if its a real
+			* GObject introspected property
+			*/
 
 	GValue *def;      /* The default value for this property (this will exist
 			   * as a copy of orig_def if not specified by the catalog)
@@ -174,30 +135,14 @@ struct _GladePropertyClass
 			     * directory).
 			     */
 	
-	/* Delagate to verify if this is a valid value for this property,
-	 * if this function exists and returns FALSE, then glade_property_set
-	 * will abort before making any changes
-	 */
-	GladeVerifyPropertyFunc verify_function;
+	gboolean transfer_on_paste; /* If this is a packing prop, 
+				     * wether we should transfer it on paste.
+				     */
+	
+	gdouble weight;	/* This will determine the position of this property in 
+			 * the editor.
+			 */
 	
-	/* If this property can't be set with g_object_set then
-	 * we need to implement it inside glade. This is a pointer
-	 * to the function that can set this property. The functions
-	 * to work arround these problems are inside glade-gtk.c
-	 */
-	GladeSetPropertyFunc set_function;
-
-	/* If this property can't be get with g_object_get then
-	 * we need to implement it inside glade. This is a pointer
-	 * to the function that can get this property. The functions
-	 * to work arround these problems are inside glade-gtk.c
-	 *
-	 * Note that since glade knows what the property values are 
-	 * at all times regardless of the objects copy, this is currently
-	 * only used to obtain the values of packing properties that are
-	 * set by the said object's parent at "container_add" time.
-	 */
-	GladeGetPropertyFunc get_function;
 };
 
 LIBGLADEUI_API
@@ -231,14 +176,14 @@ LIBGLADEUI_API
 GValue             *glade_property_class_make_gvalue_from_vl     (GladePropertyClass  *property_class,
 								  va_list              vl);
 LIBGLADEUI_API
-void                glade_property_class_set_vl_from_gvalue      (GladePropertyClass  *class,
+void                glade_property_class_set_vl_from_gvalue      (GladePropertyClass  *klass,
 								  GValue              *value,
 								  va_list              vl);
 LIBGLADEUI_API
-GValue             *glade_property_class_make_gvalue             (GladePropertyClass  *class,
+GValue             *glade_property_class_make_gvalue             (GladePropertyClass  *klass,
 								  ...);
 LIBGLADEUI_API
-void                glade_property_class_get_from_gvalue         (GladePropertyClass  *class,
+void                glade_property_class_get_from_gvalue         (GladePropertyClass  *klass,
 								  GValue              *value,
 								  ...);
 LIBGLADEUI_API
@@ -248,15 +193,15 @@ gboolean            glade_property_class_update_from_node        (GladeXmlNode
 								  GladePropertyClass **property_class,
 								  const gchar         *domain);
 LIBGLADEUI_API
-gchar              *glade_property_class_get_displayable_value   (GladePropertyClass *class, 
-								  gint                value);
+G_CONST_RETURN gchar *glade_property_class_get_displayable_value   (GladePropertyClass *klass, 
+								    gint                value);
 LIBGLADEUI_API
 GtkAdjustment      *glade_property_class_make_adjustment         (GladePropertyClass *property_class);
 LIBGLADEUI_API
-gboolean            glade_property_class_match                   (GladePropertyClass *class,
+gboolean            glade_property_class_match                   (GladePropertyClass *klass,
 								  GladePropertyClass *comp);
 LIBGLADEUI_API
-gboolean            glade_property_class_void_value              (GladePropertyClass *class,
+gboolean            glade_property_class_void_value              (GladePropertyClass *klass,
 								  GValue             *value);
 LIBGLADEUI_API
 G_CONST_RETURN gchar *glade_property_class_atk_realname          (const gchar        *atk_name);
